==> ejc-technologymanage-api-3.0.0-20221209.100713-19-sources.jar: com/ejianc/business/constructor/vo/FazdVO.java <==
package com.ejianc.business.constructor.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 方案字典实体
 * 
 * @author generator
 * 
 */
public class FazdVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String remark; // 备注
    private Integer qbm; // 全编码
    private String mc; // 名称
    private String fasm; // 方案说明
    private Integer bcbm; // 本层编码
    private Long pid; // 上级编码
    private List<FazdVO> children;
    private Integer childFlag; // 子级标志(0:否 1：是)
    private Integer status; // 字典启用状态

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Integer getQbm() {
        return qbm;
    }

    public void setQbm(Integer qbm) {
        this.qbm = qbm;
    }
    public String getMc() {
        return mc;
    }

    public void setMc(String mc) {
        this.mc = mc;
    }
    public String getFasm() {
        return fasm;
    }

    public void setFasm(String fasm) {
        this.fasm = fasm;
    }
    public Integer getBcbm() {
        return bcbm;
    }

    public void setBcbm(Integer bcbm) {
        this.bcbm = bcbm;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public List<FazdVO> getChildren() {
        return children;
    }

    public void setChildren(List<FazdVO> children) {
        this.children = children;
    }

    public Integer getChildFlag() {
        return childFlag;
    }

    public void setChildFlag(Integer childFlag) {
        this.childFlag = childFlag;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

}

==> ejc-technologymanage-api-3.0.0-20230620.015019-31-sources.jar: com/ejianc/business/constructor/vo/FazdVO.java <==
package com.ejianc.business.constructor.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 方案字典实体
 * 
 * @author generator
 * 
 */
public class FazdVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String remark; // 备注
    private Integer qbm; // 全编码
    private String mc; // 名称
    private String fasm; // 方案说明
    private Integer bcbm; // 本层编码
    private Long pid; // 上级编码
    private List<FazdVO> children;
    private Integer childFlag; // 子级标志(0:否 1：是)
    private Integer status; // 字典启用状态
    private Boolean isLeaf; // 是否是叶子节点
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Integer getQbm() {
        return qbm;
    }

    public void setQbm(Integer qbm) {
        this.qbm = qbm;
    }
    public String getMc() {
        return mc;
    }

    public void setMc(String mc) {
        this.mc = mc;
    }
    public String getFasm() {
        return fasm;
    }

    public void setFasm(String fasm) {
        this.fasm = fasm;
    }
    public Integer getBcbm() {
        return bcbm;
    }

    public void setBcbm(Integer bcbm) {
        this.bcbm = bcbm;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public List<FazdVO> getChildren() {
        return children;
    }

    public void setChildren(List<FazdVO> children) {
        this.children = children;
    }

    public Integer getChildFlag() {
        return childFlag;
    }

    public void setChildFlag(Integer childFlag) {
        this.childFlag = childFlag;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public Boolean getLeaf() {
        return isLeaf;
    }

    public void setLeaf(Boolean leaf) {
        isLeaf = leaf;
    }
}
